# Generated by roxygen2: do not edit by hand

S3method("+",hd)
S3method("+",hd_gg_theme)
S3method(as.list,hd_opts)
S3method(as.list,hd_spec)
S3method(print,hd)
S3method(print,hd_geom)
S3method(print,hd_opts)
S3method(print,hd_spec)
export(geom_args)
export(get_palette)
export(gg_theme)
export(hd)
export(hd_add_js)
export(hd_app)
export(hd_geom_arearange)
export(hd_geom_column)
export(hd_geom_line)
export(hd_geom_pie)
export(hd_geom_ranked_bar)
export(hd_geom_scatter)
export(hd_geom_stacked_column)
export(hd_make)
export(hd_opts)
export(hd_save)
export(hd_set_theme)
export(hd_spec)
export(hd_theme)
export(list_backends)
export(list_geoms)
export(list_palettes)
export(register_backend)
export(register_geom)
export(register_palette)
importFrom(rlang,.data)
importFrom(stats,setNames)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(utils,head)
importFrom(utils,modifyList)
