#' Alcohol Consumption Data
#'
#' Annual estimates of alcohol consumption, including adjusted mean values,
#' standard errors, and 95% confidence intervals. Includes an alternative
#' unit (`adj_enhet`) with corresponding uncertainty estimates.
#'
#' @format A data frame with 14 rows and 9 variables:
#'
#' @source Helsedirektoratet. \emph{Tall om alkohol}.
#'   \url{https://www.helsedirektoratet.no/rapporter/tall-om-alkohol}
#'
#' @usage NULL
#' 
"alco1"

#' Alcohol Consumption by Gender
#'
#' Annual estimates of alcohol consumption stratified by \enc{kjønn}{kjonn}
#' (gender), including adjusted means, standard errors, and 95\% confidence
#' intervals. Also includes an alternative unit (`adj_enhet`) with uncertainty.
#'
#' @format A data frame with 28 rows and 10 variables:
#'
#' @source Helsedirektoratet. \emph{Tall om alkohol}.
#'   \url{https://www.helsedirektoratet.no/rapporter/tall-om-alkohol}
#'
#' @usage NULL
#'
"alco2"
