% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.hd_add_dep}
\alias{.hd_add_dep}
\title{Version-safe hc_add_dependency wrapper}
\usage{
.hd_add_dep(chart, path)
}
\description{
highcharter 0.9.4 takes the path as a positional argument.
Older versions used name = . This wrapper handles both.
}
\keyword{internal}
