% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palettes.R
\name{get_palette}
\alias{get_palette}
\title{Retrieve a Named Palette}
\usage{
get_palette(name)
}
\arguments{
\item{name}{Character. Palette name (see \code{\link[=list_palettes]{list_palettes()}}).}
}
\value{
Character vector of colours, or \code{NULL} if not found.
}
\description{
Retrieve a Named Palette
}
\examples{
get_palette("hdir")
}
