% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/registry.R
\name{list_geoms}
\alias{list_geoms}
\title{List Registered Geometries}
\usage{
list_geoms()
}
\value{
Character vector of registered geometry names.
}
\description{
List Registered Geometries
}
