% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/registry.R
\name{register_backend}
\alias{register_backend}
\title{Register a Rendering Backend and used when loding in zzz.R file}
\usage{
register_backend(name, engine)
}
\arguments{
\item{name}{Character. Unique backend identifier (e.g. \code{"ggplot2"}).}

\item{engine}{Function.}
}
\value{
\code{name}, invisibly.
}
\description{
Register a Rendering Backend and used when loding in zzz.R file
}
