% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_columns}
\alias{check_columns}
\title{Stop with a tidy message when columns are absent from a data frame}
\usage{
check_columns(data, cols, arg_name = "data")
}
\description{
Stop with a tidy message when columns are absent from a data frame
}
\keyword{internal}
