% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dataset.R
\docType{data}
\name{alco1}
\alias{alco1}
\title{Alcohol Consumption Data}
\format{
A data frame with 14 rows and 9 variables:
}
\source{
Helsedirektoratet. \emph{Tall om alkohol}.
\url{https://www.helsedirektoratet.no/rapporter/tall-om-alkohol}
}
\description{
Annual estimates of alcohol consumption, including adjusted mean values,
standard errors, and 95\% confidence intervals. Includes an alternative
unit (\code{adj_enhet}) with corresponding uncertainty estimates.
}
\keyword{datasets}
