% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palettes.R
\name{list_palettes}
\alias{list_palettes}
\title{List Registered Palettes}
\usage{
list_palettes()
}
\value{
Character vector of registered palette names.
}
\description{
List Registered Palettes
}
\examples{
list_palettes()
}
