% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geom-scatter.R
\name{hd_geom_scatter}
\alias{hd_geom_scatter}
\title{Scatter Geometry Layer for hd Objects}
\usage{
hd_geom_scatter(dot_size = 4, ...)
}
\arguments{
\item{dot_size}{Numeric. Size of the points in the scatter plot. Default is 4.}

\item{...}{Geometry-specific arguments forwarded to \code{\link[=hd_make]{hd_make()}}.
' @return An S3 object of class \code{"hd_geom"} for use with \code{+.hd}.}
}
\value{
An S3 object of class \code{"hd_geom"} for use with \code{+.hd}.
}
\description{
\code{hd_geom_scatter()} creates a scatter geometry layer that is added to an
\code{\link[=hd]{hd()}} object via \code{+}. Use \code{\link[=geom_args]{geom_args()}} to discover available arguments per
geometry, e.g. \code{geom_args("scatter")} lists \code{dot_size}.
}
\examples{
# Basic scatter plot - layered API
hd(mtcars, x = "wt", y = "mpg", backend = "ggplot2") +
 hd_geom_scatter() +
 hd_opts(title = "Scatter Plot of mtcars")

# Basic scatter plot - declarative API
car <- hd_spec(mtcars, x = "wt", y = "mpg")
opt <- hd_opts(title = "Scatter Plot of mtcars")
hd_make(car, type = "scatter")

}
