% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.hc_symbols}
\alias{.hc_symbols}
\title{Valid Highcharts marker symbol names}
\usage{
.hc_symbols
}
\description{
Valid Highcharts marker symbol names
}
\keyword{internal}
