% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{resolve_symbols}
\alias{resolve_symbols}
\title{Resolve and validate line symbols for n groups}
\usage{
resolve_symbols(n, symbols = NULL)
}
\arguments{
\item{n}{Integer. Number of groups.}

\item{symbols}{Character vector or \code{NULL} supplied by the user.}
}
\value{
Character vector of length \code{n}.
}
\description{
Resolve and validate line symbols for n groups
}
\keyword{internal}
