% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dataset.R
\docType{data}
\name{alco2}
\alias{alco2}
\title{Alcohol Consumption by Gender}
\format{
A data frame with 28 rows and 10 variables:
}
\source{
Helsedirektoratet. \emph{Tall om alkohol}.
\url{https://www.helsedirektoratet.no/rapporter/tall-om-alkohol}
}
\description{
Annual estimates of alcohol consumption stratified by \enc{kjønn}{kjonn}
(gender), including adjusted means, standard errors, and 95\\% confidence
intervals. Also includes an alternative unit (\code{adj_enhet}) with uncertainty.
}
\keyword{datasets}
