% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/registry.R
\name{list_backends}
\alias{list_backends}
\title{List Registered Backends}
\usage{
list_backends()
}
\value{
Character vector of registered backend names.
}
\description{
List Registered Backends
}
