% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{check_ylim}
\alias{check_ylim}
\title{Validate the ylim argument}
\usage{
check_ylim(ylim)
}
\description{
Validate the ylim argument
}
\keyword{internal}
